summaryrefslogtreecommitdiff
path: root/svx
diff options
context:
space:
mode:
Diffstat (limited to 'svx')
-rw-r--r--svx/source/dialog/orienthelper.cxx20
-rw-r--r--svx/source/engine3d/float3d.cxx122
-rw-r--r--svx/source/fmcomp/gridcell.cxx20
-rw-r--r--svx/source/fmcomp/gridctrl.cxx8
-rw-r--r--svx/source/form/fmshimp.cxx4
-rw-r--r--svx/source/form/fmsrcimp.cxx4
-rw-r--r--svx/source/sidebar/paragraph/ParaPropertyPanel.cxx4
-rw-r--r--svx/source/tbxctrls/extrusioncontrols.cxx2
-rw-r--r--svx/source/tbxctrls/layctrl.cxx2
-rw-r--r--svx/source/tbxctrls/linectrl.cxx2
-rw-r--r--svx/source/tbxctrls/tbcontrl.cxx24
11 files changed, 106 insertions, 106 deletions
diff --git a/svx/source/engine3d/float3d.cxx b/svx/source/engine3d/float3d.cxx
index d659b7eb7baf..d6f926c88d7f 100644
--- a/svx/source/engine3d/float3d.cxx
+++ b/svx/source/engine3d/float3d.cxx
@@ -718,14 +718,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
aBtnDoubleSided.Check( bValue );
bUpdate = sal_True;
}
- else if( aBtnDoubleSided.GetState() == STATE_DONTKNOW )
+ else if( aBtnDoubleSided.GetState() == TRISTATE_INDET )
aBtnDoubleSided.Check( bValue );
}
else
{
- if( aBtnDoubleSided.GetState() != STATE_DONTKNOW )
+ if( aBtnDoubleSided.GetState() != TRISTATE_INDET )
{
- aBtnDoubleSided.SetState( STATE_DONTKNOW );
+ aBtnDoubleSided.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -842,14 +842,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
aBtnNormalsInvert.Check( bValue );
bUpdate = sal_True;
}
- else if( aBtnNormalsInvert.GetState() == STATE_DONTKNOW )
+ else if( aBtnNormalsInvert.GetState() == TRISTATE_INDET )
aBtnNormalsInvert.Check( bValue );
}
else
{
- if( aBtnNormalsInvert.GetState() != STATE_DONTKNOW )
+ if( aBtnNormalsInvert.GetState() != TRISTATE_INDET )
{
- aBtnNormalsInvert.SetState( STATE_DONTKNOW );
+ aBtnNormalsInvert.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -864,14 +864,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
aBtnTwoSidedLighting.Check( bValue );
bUpdate = sal_True;
}
- else if( aBtnTwoSidedLighting.GetState() == STATE_DONTKNOW )
+ else if( aBtnTwoSidedLighting.GetState() == TRISTATE_INDET )
aBtnTwoSidedLighting.Check( bValue );
}
else
{
- if( aBtnTwoSidedLighting.GetState() != STATE_DONTKNOW )
+ if( aBtnTwoSidedLighting.GetState() != TRISTATE_INDET )
{
- aBtnTwoSidedLighting.SetState( STATE_DONTKNOW );
+ aBtnTwoSidedLighting.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -909,14 +909,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
aMtrSlant.Enable( bValue );
bUpdate = sal_True;
}
- else if( aBtnShadow3d.GetState() == STATE_DONTKNOW )
+ else if( aBtnShadow3d.GetState() == TRISTATE_INDET )
aBtnShadow3d.Check( bValue );
}
else
{
- if( aBtnShadow3d.GetState() != STATE_DONTKNOW )
+ if( aBtnShadow3d.GetState() != TRISTATE_INDET )
{
- aBtnShadow3d.SetState( STATE_DONTKNOW );
+ aBtnShadow3d.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1023,14 +1023,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
SetUILightState( aBtnLight1, bOn );
bUpdate = sal_True;
}
- if( aBtnLight1.GetState() == STATE_DONTKNOW )
+ if( aBtnLight1.GetState() == TRISTATE_INDET )
aBtnLight1.Check( aBtnLight1.IsChecked() );
}
else
{
- if( aBtnLight1.GetState() != STATE_DONTKNOW )
+ if( aBtnLight1.GetState() != TRISTATE_INDET )
{
- aBtnLight1.SetState( STATE_DONTKNOW );
+ aBtnLight1.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1072,14 +1072,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
SetUILightState( aBtnLight2, bOn );
bUpdate = sal_True;
}
- if( aBtnLight2.GetState() == STATE_DONTKNOW )
+ if( aBtnLight2.GetState() == TRISTATE_INDET )
aBtnLight2.Check( aBtnLight2.IsChecked() );
}
else
{
- if( aBtnLight2.GetState() != STATE_DONTKNOW )
+ if( aBtnLight2.GetState() != TRISTATE_INDET )
{
- aBtnLight2.SetState( STATE_DONTKNOW );
+ aBtnLight2.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1121,14 +1121,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
SetUILightState( aBtnLight3, bOn );
bUpdate = sal_True;
}
- if( aBtnLight3.GetState() == STATE_DONTKNOW )
+ if( aBtnLight3.GetState() == TRISTATE_INDET )
aBtnLight3.Check( aBtnLight3.IsChecked() );
}
else
{
- if( aBtnLight3.GetState() != STATE_DONTKNOW )
+ if( aBtnLight3.GetState() != TRISTATE_INDET )
{
- aBtnLight3.SetState( STATE_DONTKNOW );
+ aBtnLight3.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1170,14 +1170,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
SetUILightState( aBtnLight4, bOn );
bUpdate = sal_True;
}
- if( aBtnLight4.GetState() == STATE_DONTKNOW )
+ if( aBtnLight4.GetState() == TRISTATE_INDET )
aBtnLight4.Check( aBtnLight4.IsChecked() );
}
else
{
- if( aBtnLight4.GetState() != STATE_DONTKNOW )
+ if( aBtnLight4.GetState() != TRISTATE_INDET )
{
- aBtnLight4.SetState( STATE_DONTKNOW );
+ aBtnLight4.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1219,14 +1219,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
SetUILightState( aBtnLight5, bOn );
bUpdate = sal_True;
}
- if( aBtnLight5.GetState() == STATE_DONTKNOW )
+ if( aBtnLight5.GetState() == TRISTATE_INDET )
aBtnLight5.Check( aBtnLight5.IsChecked() );
}
else
{
- if( aBtnLight5.GetState() != STATE_DONTKNOW )
+ if( aBtnLight5.GetState() != TRISTATE_INDET )
{
- aBtnLight5.SetState( STATE_DONTKNOW );
+ aBtnLight5.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1268,14 +1268,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
SetUILightState( aBtnLight6, bOn );
bUpdate = sal_True;
}
- if( aBtnLight6.GetState() == STATE_DONTKNOW )
+ if( aBtnLight6.GetState() == TRISTATE_INDET )
aBtnLight6.Check( aBtnLight6.IsChecked() );
}
else
{
- if( aBtnLight6.GetState() != STATE_DONTKNOW )
+ if( aBtnLight6.GetState() != TRISTATE_INDET )
{
- aBtnLight6.SetState( STATE_DONTKNOW );
+ aBtnLight6.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1317,14 +1317,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
SetUILightState( aBtnLight7 , bOn );
bUpdate = sal_True;
}
- if( aBtnLight7.GetState() == STATE_DONTKNOW )
+ if( aBtnLight7.GetState() == TRISTATE_INDET )
aBtnLight7.Check( aBtnLight7.IsChecked() );
}
else
{
- if( aBtnLight7.GetState() != STATE_DONTKNOW )
+ if( aBtnLight7.GetState() != TRISTATE_INDET )
{
- aBtnLight7.SetState( STATE_DONTKNOW );
+ aBtnLight7.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1366,14 +1366,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
SetUILightState( aBtnLight8, bOn );
bUpdate = sal_True;
}
- if( aBtnLight8.GetState() == STATE_DONTKNOW )
+ if( aBtnLight8.GetState() == TRISTATE_INDET )
aBtnLight8.Check( aBtnLight8.IsChecked() );
}
else
{
- if( aBtnLight8.GetState() != STATE_DONTKNOW )
+ if( aBtnLight8.GetState() != TRISTATE_INDET )
{
- aBtnLight8.SetState( STATE_DONTKNOW );
+ aBtnLight8.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1527,14 +1527,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
aBtnTexFilter.Check( bValue );
bUpdate = sal_True;
}
- if( aBtnTexFilter.GetState() == STATE_DONTKNOW )
+ if( aBtnTexFilter.GetState() == TRISTATE_INDET )
aBtnTexFilter.Check( bValue );
}
else
{
- if( aBtnTexFilter.GetState() != STATE_DONTKNOW )
+ if( aBtnTexFilter.GetState() != TRISTATE_INDET )
{
- aBtnTexFilter.SetState( STATE_DONTKNOW );
+ aBtnTexFilter.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1640,14 +1640,14 @@ void Svx3DWin::Update( SfxItemSet& rAttrs )
aBtnPerspective.Check( ePT == PR_PERSPECTIVE );
bUpdate = sal_True;
}
- if( aBtnPerspective.GetState() == STATE_DONTKNOW )
+ if( aBtnPerspective.GetState() == TRISTATE_INDET )
aBtnPerspective.Check( ePT == PR_PERSPECTIVE );
}
else
{
- if( aBtnPerspective.GetState() != STATE_DONTKNOW )
+ if( aBtnPerspective.GetState() != TRISTATE_INDET )
{
- aBtnPerspective.SetState( STATE_DONTKNOW );
+ aBtnPerspective.SetState( TRISTATE_INDET );
bUpdate = sal_True;
}
}
@@ -1731,7 +1731,7 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
//Others must stand as the front on all sides
// Perspective
- if( aBtnPerspective.GetState() != STATE_DONTKNOW )
+ if( aBtnPerspective.GetState() != TRISTATE_INDET )
{
sal_uInt16 nValue;
if( aBtnPerspective.IsChecked() )
@@ -1784,9 +1784,9 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
// Double-sided
TriState eState = aBtnDoubleSided.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
- sal_Bool bValue = STATE_CHECK == eState;
+ sal_Bool bValue = TRISTATE_TRUE == eState;
rAttrs.Put(Svx3DDoubleSidedItem(bValue));
}
else
@@ -1835,9 +1835,9 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
// Normal inverted
eState = aBtnNormalsInvert.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
- sal_Bool bValue = STATE_CHECK == eState;
+ sal_Bool bValue = TRISTATE_TRUE == eState;
rAttrs.Put(Svx3DNormalsInvertItem(bValue));
}
else
@@ -1845,9 +1845,9 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
// 2-sided lighting
eState = aBtnTwoSidedLighting.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
- sal_Bool bValue = STATE_CHECK == eState;
+ sal_Bool bValue = TRISTATE_TRUE == eState;
rAttrs.Put(Svx3DTwoSidedLightingItem(bValue));
}
else
@@ -1865,9 +1865,9 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
// 3D-Shadow
eState = aBtnShadow3d.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
- sal_Bool bValue = STATE_CHECK == eState;
+ sal_Bool bValue = TRISTATE_TRUE == eState;
rAttrs.Put(Svx3DShadow3DItem(bValue));
rAttrs.Put(SdrShadowItem(bValue));
}
@@ -1920,7 +1920,7 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
rAttrs.InvalidateItem(SDRATTR_3DSCENE_LIGHTCOLOR_1);
// Light 1 (on/off)
eState = aBtnLight1.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
sal_Bool bValue = GetUILightState( aBtnLight1 );
rAttrs.Put(Svx3DLightOnOff1Item(bValue));
@@ -1945,7 +1945,7 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
rAttrs.InvalidateItem(SDRATTR_3DSCENE_LIGHTCOLOR_2);
// Light 2 (on/off)
eState = aBtnLight2.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
sal_Bool bValue = GetUILightState( aBtnLight2 );
rAttrs.Put(Svx3DLightOnOff2Item(bValue));
@@ -1969,7 +1969,7 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
rAttrs.InvalidateItem(SDRATTR_3DSCENE_LIGHTCOLOR_3);
// Light 3 (on/off)
eState = aBtnLight3.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
sal_Bool bValue = GetUILightState( aBtnLight3 );
rAttrs.Put(Svx3DLightOnOff3Item(bValue));
@@ -1993,7 +1993,7 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
rAttrs.InvalidateItem(SDRATTR_3DSCENE_LIGHTCOLOR_4);
// Light 4 (on/off)
eState = aBtnLight4.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
sal_Bool bValue = GetUILightState( aBtnLight4 );
rAttrs.Put(Svx3DLightOnOff4Item(bValue));
@@ -2017,7 +2017,7 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
rAttrs.InvalidateItem(SDRATTR_3DSCENE_LIGHTCOLOR_5);
// Light 5 (on/off)
eState = aBtnLight5.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
sal_Bool bValue = GetUILightState( aBtnLight5 );
rAttrs.Put(Svx3DLightOnOff5Item(bValue));
@@ -2041,7 +2041,7 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
rAttrs.InvalidateItem(SDRATTR_3DSCENE_LIGHTCOLOR_6);
// Light 6 (on/off)
eState = aBtnLight6.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
sal_Bool bValue = GetUILightState( aBtnLight6 );
rAttrs.Put(Svx3DLightOnOff6Item(bValue));
@@ -2065,7 +2065,7 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
rAttrs.InvalidateItem(SDRATTR_3DSCENE_LIGHTCOLOR_7);
// Light 7 (on/off)
eState = aBtnLight7.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
sal_Bool bValue = GetUILightState( aBtnLight7 );
rAttrs.Put(Svx3DLightOnOff7Item(bValue));
@@ -2089,7 +2089,7 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
rAttrs.InvalidateItem(SDRATTR_3DSCENE_LIGHTCOLOR_8);
// Light 8 (on/off)
eState = aBtnLight8.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
sal_Bool bValue = GetUILightState( aBtnLight8 );
rAttrs.Put(Svx3DLightOnOff8Item(bValue));
@@ -2169,9 +2169,9 @@ void Svx3DWin::GetAttr( SfxItemSet& rAttrs )
// Filter
eState = aBtnTexFilter.GetState();
- if( eState != STATE_DONTKNOW )
+ if( eState != TRISTATE_INDET )
{
- sal_Bool bValue = STATE_CHECK == eState;
+ sal_Bool bValue = TRISTATE_TRUE == eState;
rAttrs.Put(Svx3DTextureFilterItem(bValue));
}
else
diff --git a/svx/source/fmcomp/gridcell.cxx b/svx/source/fmcomp/gridcell.cxx
index aca59abe9bc6..4acf5a73ab94 100644
--- a/svx/source/fmcomp/gridcell.cxx
+++ b/svx/source/fmcomp/gridcell.cxx
@@ -1707,14 +1707,14 @@ CellControllerRef DbCheckBox::CreateController() const
static void lcl_setCheckBoxState( const Reference< ::com::sun::star::sdb::XColumn >& _rxField,
CheckBoxControl* _pCheckBoxControl )
{
- TriState eState = STATE_DONTKNOW;
+ TriState eState = TRISTATE_INDET;
if (_rxField.is())
{
try
{
sal_Bool bValue = _rxField->getBoolean();
if (!_rxField->wasNull())
- eState = bValue ? STATE_CHECK : STATE_NOCHECK;
+ eState = bValue ? TRISTATE_TRUE : TRISTATE_FALSE;
}
catch( const Exception& )
{
@@ -1744,7 +1744,7 @@ void DbCheckBox::updateFromModel( Reference< XPropertySet > _rxModel )
{
OSL_ENSURE( _rxModel.is() && m_pWindow, "DbCheckBox::updateFromModel: invalid call!" );
- sal_Int16 nState = STATE_DONTKNOW;
+ sal_Int16 nState = TRISTATE_INDET;
_rxModel->getPropertyValue( FM_PROP_STATE ) >>= nState;
static_cast< CheckBoxControl* >( m_pWindow )->GetBox().SetState( static_cast< TriState >( nState ) );
}
@@ -3028,11 +3028,11 @@ void DbFilterField::SetText(const OUString& rText)
{
TriState eState;
if (rText == "1")
- eState = STATE_CHECK;
+ eState = TRISTATE_TRUE;
else if (rText == "0")
- eState = STATE_NOCHECK;
+ eState = TRISTATE_FALSE;
else
- eState = STATE_DONTKNOW;
+ eState = TRISTATE_INDET;
((CheckBoxControl*)m_pWindow)->GetBox().SetState(eState);
((CheckBoxControl*)m_pPainter)->GetBox().SetState(eState);
@@ -3191,13 +3191,13 @@ IMPL_LINK_NOARG(DbFilterField, OnClick)
switch (eState)
{
- case STATE_CHECK:
+ case TRISTATE_TRUE:
aText = "1";
break;
- case STATE_NOCHECK:
+ case TRISTATE_FALSE:
aText = "0";
break;
- case STATE_DONTKNOW:
+ case TRISTATE_INDET:
break;
}
@@ -4008,7 +4008,7 @@ short SAL_CALL FmXCheckBoxCell::getState() throw( RuntimeException )
UpdateFromColumn();
return (short)m_pBox->GetState();
}
- return STATE_DONTKNOW;
+ return TRISTATE_INDET;
}
diff --git a/svx/source/fmcomp/gridctrl.cxx b/svx/source/fmcomp/gridctrl.cxx
index b503013335f0..01b6e490bb27 100644
--- a/svx/source/fmcomp/gridctrl.cxx
+++ b/svx/source/fmcomp/gridctrl.cxx
@@ -3643,17 +3643,17 @@ Reference< XAccessible > DbGridControl::CreateAccessibleCell( sal_Int32 _nRow, s
Reference< ::com::sun::star::awt::XCheckBox> xBox(xInt,UNO_QUERY);
if ( xBox.is() )
{
- TriState eValue = STATE_NOCHECK;
+ TriState eValue = TRISTATE_FALSE;
switch( xBox->getState() )
{
case 0:
- eValue = STATE_NOCHECK;
+ eValue = TRISTATE_FALSE;
break;
case 1:
- eValue = STATE_CHECK;
+ eValue = TRISTATE_TRUE;
break;
case 2:
- eValue = STATE_DONTKNOW;
+ eValue = TRISTATE_INDET;
break;
}
return DbGridControl_Base::CreateAccessibleCheckBoxCell( _nRow, _nColumnPos,eValue );
diff --git a/svx/source/form/fmshimp.cxx b/svx/source/form/fmshimp.cxx
index 0e2d40a30fb3..85e80bb37bde 100644
--- a/svx/source/form/fmshimp.cxx
+++ b/svx/source/form/fmshimp.cxx
@@ -511,8 +511,8 @@ sal_Bool IsSearchableControl( const ::com::sun::star::uno::Reference< ::com::sun
{
switch ( (::TriState)xCheckBox->getState() )
{
- case STATE_NOCHECK: *_pCurrentText = "0"; break;
- case STATE_CHECK: *_pCurrentText = "1"; break;
+ case TRISTATE_FALSE: *_pCurrentText = "0"; break;
+ case TRISTATE_TRUE: *_pCurrentText = "1"; break;
default: *_pCurrentText = ""; break;
}
}
diff --git a/svx/source/form/fmsrcimp.cxx b/svx/source/form/fmsrcimp.cxx
index 3816ab40fddb..2a11166b00a1 100644
--- a/svx/source/form/fmsrcimp.cxx
+++ b/svx/source/form/fmsrcimp.cxx
@@ -201,8 +201,8 @@ OUString CheckBoxWrapper::getCurrentText() const
{
switch ((TriState)m_xBox->getState())
{
- case STATE_NOCHECK: return OUString("0");
- case STATE_CHECK: return OUString("1");
+ case TRISTATE_FALSE: return OUString("0");
+ case TRISTATE_TRUE: return OUString("1");
default: break;
}
return OUString();
diff --git a/svx/source/sidebar/paragraph/ParaPropertyPanel.cxx b/svx/source/sidebar/paragraph/ParaPropertyPanel.cxx
index 37b7a4ad151b..872c645cd982 100644
--- a/svx/source/sidebar/paragraph/ParaPropertyPanel.cxx
+++ b/svx/source/sidebar/paragraph/ParaPropertyPanel.cxx
@@ -1010,13 +1010,13 @@ void ParaPropertyPanel::StateChangeBulletNumImpl( sal_uInt16 nSID, SfxItemState
{
mpTBxNumBullet->SetItemState(
nIdNumber,
- aBool ? STATE_CHECK : STATE_NOCHECK );
+ aBool ? TRISTATE_TRUE : TRISTATE_FALSE );
}
else if (nSID==FN_NUM_BULLET_ON)
{
mpTBxNumBullet->SetItemState(
nIdBullet,
- aBool ? STATE_CHECK : STATE_NOCHECK );
+ aBool ? TRISTATE_TRUE : TRISTATE_FALSE );
}
}
}
diff --git a/svx/source/tbxctrls/extrusioncontrols.cxx b/svx/source/tbxctrls/extrusioncontrols.cxx
index eb49b9e77f62..aafeed7b7bfe 100644
--- a/svx/source/tbxctrls/extrusioncontrols.cxx
+++ b/svx/source/tbxctrls/extrusioncontrols.cxx
@@ -1021,7 +1021,7 @@ void ExtrusionColorControl::StateChanged( sal_uInt16 nSID, SfxItemState eState,
}
rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
- rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? STATE_DONTKNOW : STATE_NOCHECK );
+ rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? TRISTATE_INDET : TRISTATE_FALSE );
}
}
diff --git a/svx/source/tbxctrls/layctrl.cxx b/svx/source/tbxctrls/layctrl.cxx
index 1d5aa7688f54..16ea98a21673 100644
--- a/svx/source/tbxctrls/layctrl.cxx
+++ b/svx/source/tbxctrls/layctrl.cxx
@@ -778,7 +778,7 @@ void SvxTableToolBoxControl::StateChanged( sal_uInt16, SfxItemState eState, cons
rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
rTbx.SetItemState( nId,
- ( SFX_ITEM_DONTCARE == eState ) ? STATE_DONTKNOW : STATE_NOCHECK );
+ ( SFX_ITEM_DONTCARE == eState ) ? TRISTATE_INDET : TRISTATE_FALSE );
}
// class SvxColumnsToolBoxControl ------------------------------------------
diff --git a/svx/source/tbxctrls/linectrl.cxx b/svx/source/tbxctrls/linectrl.cxx
index 29586d4f997a..78303aa1ff86 100644
--- a/svx/source/tbxctrls/linectrl.cxx
+++ b/svx/source/tbxctrls/linectrl.cxx
@@ -752,7 +752,7 @@ void SvxLineEndToolBoxControl::StateChanged( sal_uInt16, SfxItemState eState, co
ToolBox& rTbx = GetToolBox();
rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
- rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? STATE_DONTKNOW : STATE_NOCHECK );
+ rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? TRISTATE_INDET : TRISTATE_FALSE );
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/svx/source/tbxctrls/tbcontrl.cxx b/svx/source/tbxctrls/tbcontrl.cxx
index b282f8fb016f..c40c639fb248 100644
--- a/svx/source/tbxctrls/tbcontrl.cxx
+++ b/svx/source/tbxctrls/tbcontrl.cxx
@@ -2190,7 +2190,7 @@ void SvxStyleToolBoxControl::StateChanged(
sal_uInt16 nId = GetId();
ToolBox& rTbx = GetToolBox();
SvxStyleBox_Impl* pBox = (SvxStyleBox_Impl*)(rTbx.GetItemWindow( nId ));
- TriState eTri = STATE_NOCHECK;
+ TriState eTri = TRISTATE_FALSE;
DBG_ASSERT( pBox, "Control not found!" );
@@ -2205,12 +2205,12 @@ void SvxStyleToolBoxControl::StateChanged(
{
case SFX_ITEM_AVAILABLE:
eTri = ((const SfxBoolItem*)pState)->GetValue()
- ? STATE_CHECK
- : STATE_NOCHECK;
+ ? TRISTATE_TRUE
+ : TRISTATE_FALSE;
break;
case SFX_ITEM_DONTCARE:
- eTri = STATE_DONTKNOW;
+ eTri = TRISTATE_INDET;
break;
}
@@ -2373,7 +2373,7 @@ void SvxFontColorToolBoxControl::StateChanged(
}
rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
- rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? STATE_DONTKNOW : STATE_NOCHECK );
+ rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? TRISTATE_INDET : TRISTATE_FALSE );
}
//========================================================================
@@ -2445,7 +2445,7 @@ void SvxColorToolBoxControl::StateChanged(
sal_uInt16 nId = GetId();
ToolBox& rTbx = GetToolBox();
rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
- rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? STATE_DONTKNOW : STATE_NOCHECK );
+ rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? TRISTATE_INDET : TRISTATE_FALSE );
}
//========================================================================
@@ -2563,7 +2563,7 @@ void SvxColorExtToolBoxControl::StateChanged(
ToolBox& rTbx = GetToolBox();
sal_uInt16 nId = GetId();
rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
- rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? STATE_DONTKNOW : STATE_NOCHECK );
+ rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? TRISTATE_INDET : TRISTATE_FALSE );
if (bChoiceFromPalette)
{
@@ -2679,8 +2679,8 @@ void SvxFrameToolBoxControl::StateChanged(
rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
rTbx.SetItemState( nId, (SFX_ITEM_DONTCARE == eState)
- ? STATE_DONTKNOW
- : STATE_NOCHECK );
+ ? TRISTATE_INDET
+ : TRISTATE_FALSE );
}
//========================================================================
@@ -2729,8 +2729,8 @@ void SvxFrameLineStyleToolBoxControl::StateChanged(
rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
rTbx.SetItemState( nId, (SFX_ITEM_DONTCARE == eState)
- ? STATE_DONTKNOW
- : STATE_NOCHECK );
+ ? TRISTATE_INDET
+ : TRISTATE_FALSE );
}
//========================================================================
@@ -2791,7 +2791,7 @@ void SvxFrameLineColorToolBoxControl::StateChanged(
sal_uInt16 nId = GetId();
ToolBox& rTbx = GetToolBox();
rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
- rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? STATE_DONTKNOW : STATE_NOCHECK );
+ rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? TRISTATE_INDET : TRISTATE_FALSE );
const SvxColorItem* pItem = 0;
if ( SFX_ITEM_DONTCARE != eState )
diff --git a/svx/source/dialog/orienthelper.cxx b/svx/source/dialog/orienthelper.cxx
index 14ffd752a4d8..c931e7b636cc 100644
--- a/svx/source/dialog/orienthelper.cxx
+++ b/svx/source/dialog/orienthelper.cxx
@@ -60,8 +60,8 @@ OrientationHelper_Impl::OrientationHelper_Impl( DialControl& rCtrlDial, CheckBox
mbEnabled( rCtrlDial.IsEnabled() ),
mbVisible( rCtrlDial.IsVisible() )
{
- maWinVec.push_back( WindowPair( &mrCtrlDial, STATE_CHECK ) );
- maWinVec.push_back( WindowPair( &mrCbStacked, STATE_DONTKNOW ) );
+ maWinVec.push_back( WindowPair( &mrCtrlDial, TRISTATE_TRUE ) );
+ maWinVec.push_back( WindowPair( &mrCbStacked, TRISTATE_INDET ) );
mrCbStacked.SetClickHdl( LINK( this, OrientationHelper_Impl, ClickHdl ) );
}
@@ -82,10 +82,10 @@ void OrientationHelper_Impl::EnableWindow( Window& rWindow, TriState eDisableIfS
bool bDisableOnStacked = false;
switch( eDisableIfStacked )
{
- // STATE_CHECK: Disable window, if stacked text is turned on or "don't know".
- case STATE_CHECK: bDisableOnStacked = (mrCbStacked.GetState() != STATE_NOCHECK); break;
- // STATE_NOCHECK: Disable window, if stacked text is turned off or "don't know".
- case STATE_NOCHECK: bDisableOnStacked = (mrCbStacked.GetState() != STATE_CHECK); break;
+ // TRISTATE_TRUE: Disable window, if stacked text is turned on or "don't know".
+ case TRISTATE_TRUE: bDisableOnStacked = (mrCbStacked.GetState() != TRISTATE_FALSE); break;
+ // TRISTATE_FALSE: Disable window, if stacked text is turned off or "don't know".
+ case TRISTATE_FALSE: bDisableOnStacked = (mrCbStacked.GetState() != TRISTATE_TRUE); break;
default: ;//prevent warning
}
rWindow.Enable( mbEnabled && !bDisableOnStacked );
@@ -162,23 +162,23 @@ OrientStackedWrapper::OrientStackedWrapper( OrientationHelper& rOrientHlp ) :
bool OrientStackedWrapper::IsControlDontKnow() const
{
- return GetControl().GetStackedState() == STATE_DONTKNOW;
+ return GetControl().GetStackedState() == TRISTATE_INDET;
}
void OrientStackedWrapper::SetControlDontKnow( bool bSet )
{
GetControl().EnableStackedTriState( bSet );
- GetControl().SetStackedState( bSet ? STATE_DONTKNOW : STATE_NOCHECK );
+ GetControl().SetStackedState( bSet ? TRISTATE_INDET : TRISTATE_FALSE );
}
bool OrientStackedWrapper::GetControlValue() const
{
- return GetControl().GetStackedState() == STATE_CHECK;
+ return GetControl().GetStackedState() == TRISTATE_TRUE;
}
void OrientStackedWrapper::SetControlValue( bool bValue )
{
- GetControl().SetStackedState( bValue ? STATE_CHECK : STATE_NOCHECK );
+ GetControl().SetStackedState( bValue ? TRISTATE_TRUE : TRISTATE_FALSE );
}
// ============================================================================